@@ -11,7 +11,7 @@ class StateMachine():
     context = Context()
     sm = StateMachine(context, state_creator_dict=state_creator_dict, transition_dict=transition_dict)
 
-    sm.arrive("[Init]") # Init状態は作っておいてください
+    sm._arrive("[Init]") # Init状態は作っておいてください
     """
 
     def __init__(self, context=None, state_creator_dict={}, transition_dict={}, intermachine=None, name=None):
@@ -92,9 +92,9 @@ class StateMachine():
         return self._name
 
     def start(self, next_state_name):
-        """まず state_machine.arrive(...) を行い、
-        そのあと leave(...), arrive(...) のペアを無限に繰り返します。
-        leave(...) に渡す line 引数は arrive(...) から返しますが、
+        """まず state_machine._arrive(...) を行い、
+        そのあと _leave(...), _arrive(...) のペアを無限に繰り返します。
+        _leave(...) に渡す line 引数は _arrive(...) から返しますが、
         代わりに None を返すと self.lines_getter() が実行されます。
         self.lines_getter() は、 line のリストを返す関数です。
         self.lines_getter() が None を返すとループを抜けます
@@ -102,16 +102,21 @@ class StateMachine():
         if self._is_terminate:
             return
 
-        self.arrive_sequence(next_state_name)
-        self.leave_and_loop()
+        # Arrive と Leave はペアになります
+        # Leave が終わったところで IsTerminate を判定します
 
-    def leave_and_loop(self):
-        """まず state_machine.leave(...) を行い、
-        そのあと arrive(...), leave(...) のペアを無限に繰り返します。
-        leave(...) に渡す line 引数は、
-        lines_getter() を実行することでリストで取得できるようにしてください。
-        lines_getter() が None を返すとループを抜けます
-        """
+        # Arrive sequence
+        interrupt_line = self._arrive(next_state_name)
+
+        while interrupt_line:
+            next_state_name = self._leave(interrupt_line)
+            if self._is_terminate:
+                return
+
+            interrupt_line = self._arrive(next_state_name)
+        #
+
+        # Leave and loop
         if self._is_terminate:
             return
 
@@ -124,29 +129,22 @@ class StateMachine():
 
                 self.on_line(line)
 
-                next_state_name = self.leave(line)
-                self.arrive_sequence(next_state_name)
+                next_state_name = self._leave(line)
+                if self._is_terminate:
+                    return
 
-    def arrive_sequence(self, next_state_name):
-        """arrive(next_state_name) の拡張版。
-        このステートを通り過ぎる指定があったなら、次の leave(...) まで行います。
-        通り過ぎる指定がなくなるまで続けます
+                # Arrive sequence
 
-        Parameters
-        ----------
-        str : next_state_name
-            次の状態の名前
-        """
-        if self._is_terminate:
-            return
+                interrupt_line = self._arrive(next_state_name)
 
-        interrupt_line = self.arrive(next_state_name)
+                while interrupt_line:
+                    next_state_name = self._leave(interrupt_line)
+                    if self._is_terminate:
+                        return
 
-        # interrupt_line の指定があったら、次の leave をすぐ行います
-        while interrupt_line:
-            next_state_name = self.leave(interrupt_line)
-
-            interrupt_line = self.arrive(next_state_name)
+                    interrupt_line = self._arrive(next_state_name)
+                #
+        #
 
     def _alternate_state_machine_name(self):
         if self.name is None:
@@ -154,7 +152,7 @@ class StateMachine():
         else:
             return self.name
 
-    def arrive(self, next_state_name):
+    def _arrive(self, next_state_name):
         """指定の状態に遷移します
         entryコールバック関数を呼び出します。
 
@@ -166,7 +164,7 @@ class StateMachine():
         Returns
         -------
         object
-            ただちに leave に渡したい引数。無ければ None
+            ただちに _leave に渡したい引数。無ければ None
         """
 
         if self._is_terminate:
@@ -196,7 +194,7 @@ class StateMachine():
             # Error
             raise ValueError(f"Next state [{next_state_name}] is not found")
 
-    def leave(self, line):
+    def _leave(self, line):
         """次の状態の名前と、遷移に使ったキーを返します。
         exitコールバック関数を呼び出します。
         stateの遷移はまだ行いません
@@ -269,7 +267,11 @@ class StateMachine():
                     f"Edge[{i}] is not found. name=[{edge}] path=[{self._edge_path}]")
 
         # 最後に、次のエッジへ下りていきましょう
-        if next_edge_name in curr_dict:
+        if next_edge_name == '':
+            # （Noneではなく）空文字を指定したら、踏みとどまります
+            next_state_name = self.state.name  # まだ現在のステートです
+
+        elif next_edge_name in curr_dict:
             # ディクショナリーか、文字列のどちらかです
             obj = curr_dict[next_edge_name]
 
